import { Router } from 'express'
import health from '@cloudnative/health-connect'
import * as redis from '../redis.js'
import { getLatestVersion } from '../version.js'
import { once } from '../util.js'
import { config } from '../config.js'

const router = Router()
const healthCheck = new health.HealthChecker()

if (redis.isEnabled()) {
  const redisReady = new health.ReadinessCheck('Redis ready', redis.isReady)
  healthCheck.registerReadinessCheck(redisReady)
}

const checkLatestVersion = new health.StartupCheck('check latest version', once(async function () {
  // config is required before the first version check
  await config.load()
  await getLatestVersion()
}))
healthCheck.registerStartupCheck(checkLatestVersion)

router.use('/live', health.LivenessEndpoint(healthCheck))
router.use('/ready', health.ReadinessEndpoint(healthCheck))
router.use('/healthy', health.HealthEndpoint(healthCheck))

export default router
